@@ -1,25 +1,20 @@
 CAvariants <-
 function(
-  Xtable, mj=NULL,mi=NULL, printdims=4,firstaxis=1,lastaxis=2,
-  catype = "CA",digits=4) { 
-if (printdims<1) stop(paste("Attention: number of dims for output must be at least 1\n\n"))
+  Xtable, mj=NULL,mi=NULL,firstaxis=1,lastaxis=2,
+  catype = "CA",ellcomp=TRUE,Mell=min(nrow(Xtable),ncol(Xtable))-1,alpha=0.05) { 
+#if (printdims<1) stop(paste("Attention: number of dims for output must be at least 1\n\n"))
 if (lastaxis<2) stop(paste("Attention: last axis must be at least 2\n\n"))
 if (!any(catype==c("CA","SOCA","DOCA","NSCA","SONSCA","DONSCA"))) stop(paste("Must be CA, DOCA, SOCA, NSCA, SONSCA or DONSCA"))
-
 #if (!any(is.wholenumber(Xtable))) stop(paste("Must be integer values in contingency table"))
-
 # READ DATA FILE
 #  assume for now header and row names exist
-
 #Xtable <- read.table(file = datafile, header=header)
-
 #if (header==FALSE) { 
 #for (i in 1:dim(Xtable)[1]) rownames(Xtable)[i] <- paste("r",i,sep="")
 #for (i in 1:dim(Xtable)[2]) colnames(Xtable)[i] <- paste("c",i,sep="")
 #}
-
 X <- as.matrix(Xtable)
-#M<-min(nrow(Xtable),ncol(Xtable))-1
+M<-min(nrow(Xtable),ncol(Xtable))-1
   rowlabels <- rownames(Xtable)
   collabels <- colnames(Xtable) 
 
@@ -34,18 +29,17 @@ if (is.null(mi)){
    mi <- c(1:rows)}
 else 
 mi<-c(mi)  #natural scores for rows
-maxaxes <- min(rows,cols)-1
-r<-maxaxes
+r<- min(rows,cols)-1
 S <- switch(catype, "CA"=cabasic(X),  "SOCA"=socabasic(X,mj),"DOCA"=docabasic(X,mi,mj),"NSCA"=nscabasic(X),"SONSCA"=sonscabasic(X,mj),
 "DONSCA"=donscabasic(X,mi,mj))
 
 ##########################------CA
 if(catype=="CA"){
-Fmat <- S@RX %*% S@Rweights %*% S@Raxes
-Gmat <- S@CX %*% S@Cweights %*% S@Caxes
+Fmat <- S@RX %*% S@Rweights %*% S@Raxes[,1:r]
+Gmat <- S@CX %*% S@Cweights %*% S@Caxes[,1:r]
 #dmum1 <- diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
-Fbi <- S@Cweights %*%  S@Caxes # no orthonormal
-Gbi <-S@Rweights %*%   S@Raxes # no orthonormal
+Fbi <- S@Cweights %*%  S@Caxes[,1:r] # no orthonormal
+Gbi <-S@Rweights %*%   S@Raxes[,1:r] # no orthonormal
 pcc <- t(S@CX)
 #dimnames(pcc)<-dimnames(X)
 tau=NULL
@@ -54,20 +48,22 @@ inertia <- (S@mu[1:r]*S@mu[1:r])
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(Gbi[,firstaxis:lastaxis]))
 Z<-Trend
+dimnames(Z) <- list(rowlabels,collabels)
+
 }
 #########################################################---------DOCA
 if(catype=="DOCA"){
 Z<-S@Z/sqrt(n)
 pcc<-S@RX #centered column profile matrix
-Gbi <- S@Raxes
-Fbi<- S@Caxes 
-Gmat <-  S@CX %*%  S@Caxes #row principal coordinates
-Fmat <- S@RX  %*% S@Raxes #column principal coordinates
+Gbi <- S@Raxes[,1:r]
+Fbi<- S@Caxes[,1:r] 
+Gmat <-  S@CX %*%  S@Caxes[,1:r] #row principal coordinates
+Fmat <- S@RX  %*% S@Raxes[,1:r] #column principal coordinates
+if (rows>2){
 if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){
 Gmat<-(-1)*Gmat
 Fmat<-(-1)*Fmat
-}
-
+}}
 reconstruction<-t(Gmat%*%t(S@Cweights%*%Fbi))
 dimnames(reconstruction)<-dimnames(X)
 inertia <- S@mu[1:r]/n #number of inertia of row poly
@@ -75,8 +71,13 @@ inertia2<-S@mu2[1:r]/n #number of inertias of column poly
 Z1<-S@Z
 tau=NULL
 tauden=NULL
-comps <- compstable.exe(Z1) 
-Icompnames <- c( "Location", "Dispersion", "Cubic","Error", "** Chi-squared Statistic **")
+comps <- compstable.exe(Z1)
+#browser() 
+if (rows>2){
+Icompnames <- c( "Location", "Dispersion", "Cubic","Error", "** Chi-squared Statistic **")}
+else{
+Icompnames <- c( "Location", "** Chi-squared Statistic **")}
+
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("u", 1:(rows - 1),sep=""), paste("v", 1:(cols - 1),sep=""))
 dimnames(comps$compsR) <- list(paste(Icompnames), paste(Jcompnames))
@@ -90,11 +91,11 @@ if(catype=="SOCA"){
 pcc<-S@RX
 Z<-S@Z/sqrt(n)
 dimnames(pcc)<-dimnames(X)
-Gmat <- S@CX %*%  S@Caxes #row principal coordinates
-Fmat <- S@RX %*% S@Rweights %*% S@Raxes #column principal coordinates
+Gmat <- S@CX %*%  S@Caxes[,1:r] #row principal coordinates
+Fmat <- S@RX %*% S@Rweights %*% S@Raxes[,1:r] #column principal coordinates
 if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
-Gbi <-S@Raxes
-Fbi <- S@Caxes 
+Gbi <-S@Raxes[,1:r]
+Fbi <- S@Caxes[,1:r] 
 inertia <- (S@mu[1:r]^2)/n
 inertia2<-(S@mu2[1:r])/n
 #inertia2<-(S@mu2[-1])/n
@@ -107,15 +108,15 @@ comps <- compsonetable.exe(Z1)
 Icompnames <- c( "Location", "Dispersion","Cubic", "Error", "** Chi-squared Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("m", 1:nrow(Z),sep="" ), paste("v", 1:(cols - 1),sep=""))
-dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
+dimnames(comps$comps) <- list(Icompnames, Jcompnames)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S@Rweights%*%Gbi[,firstaxis:lastaxis]))
 #browser()
 }
 
 ####################################-------------NSCA
 if(catype=="NSCA"){
-Fbi <-  S@Caxes
-Gbi <-   S@Raxes 
+Fbi <-  S@Caxes[,1:r]
+Gbi <-   S@Raxes[,1:r] 
 #dmum1 <-diag( (S@mu + (S@mu==0)) * (1-(S@mu==0)) )
 dmum1 <-diag( S@mu [1:r])
 pcc<-S@RX
@@ -128,17 +129,18 @@ tau<-sum(inertia)/tauden
 comps<-diag(inertia)
 Trend<-(Fmat[,firstaxis:lastaxis]%*%t(S@Rweights%*%Gbi[,firstaxis:lastaxis]))
 Z<-Trend
+dimnames(Z) <- list(rowlabels,collabels)
 
 }
 ##################################-------------DONSCA
 if(catype=="DONSCA"){
-Fbi <- S@Caxes
-Gbi<-S@Raxes
+Fbi <- S@Caxes[,1:r]
+Gbi<-S@Raxes[,1:r]
 pcc<-S@RX
 Z<-S@Z
 dimnames(pcc)<-dimnames(X)
-Gmat <-  S@CX %*% S@Cweights %*% S@Caxes #row principal coordinates
-Fmat <- S@RX  %*% S@Rweights %*% S@Raxes #column principal coordinates
+Gmat <-  S@CX %*% S@Cweights %*% S@Caxes[,1:r] #row principal coordinates
+Fmat <- S@RX  %*% S@Rweights %*% S@Raxes[,1:r] #column principal coordinates
 if  ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat}
 inertia <- S@mu[1:r]
 inertia2<-S@mu2[1:r] 
@@ -163,11 +165,11 @@ if(catype=="SONSCA"){
 pcc<-S@RX
 dimnames(pcc)<-dimnames(X)
 Z<-S@Z
-Gmat <- S@CX %*% S@Cweights %*% S@Caxes #column principal coordinates with principal axes
-Fmat <- S@RX %*% (S@Rweights) %*% S@Raxes #row principal coordinates with polys
-Gbi <- S@Raxes
+Gmat <- S@CX %*% S@Cweights %*% S@Caxes[,1:r] #column principal coordinates with principal axes
+Fmat <- S@RX %*% (S@Rweights) %*% S@Raxes[,1:r] #row principal coordinates with polys
+Gbi <- S@Raxes[,1:r]
 #Gbi<-(sqrt(S@Rweights))%*%S@Raxes
-Fbi <- S@Caxes 
+Fbi <- S@Caxes[,1:r] 
 if ((Z[1,1]<0) & (Z[1,2]>0)||(Z[1,1]>0) & (Z[1,2]<0)){Gmat<-(-1)*Gmat
 #Fbi<-(-1)*Fbi
 }
@@ -180,7 +182,7 @@ comps <- compsonetable.exe(Z1)
 Icompnames <- c( "Location", "Dispersion", "Cubic","Error", "** C-Statistic **")
 Jcompnames <- c("Component Value", "P-value")
 dimnames(Z) <- list(paste("m", 1:nrow(S@Z),sep=""), paste("v", 1:(cols - 1),sep=""))
-dimnames(comps) <- list(paste(Icompnames), paste(Jcompnames))
+dimnames(comps$comps) <- list(Icompnames, Jcompnames)
 Trend<-t(Gmat[,firstaxis:lastaxis]%*%t(Fbi[,firstaxis:lastaxis]))
 
 #browser()
@@ -194,19 +196,18 @@ Trend<-t(Gmat[,firstaxis:lastaxis]%*%t(Fbi[,firstaxis:lastaxis]))
 inertiasum <- sum(inertia)
 inertiapc <- 100*inertia/inertiasum
 cuminertiapc <- cumsum(inertiapc)
-inertiapc <- round(100*inertiapc)/100
-cuminertiapc <- round(100*cuminertiapc)/100
-inertias <- round(cbind(inertia,inertiapc,cuminertiapc),digits=digits)
-#browser()
+inertiapc <- (100*inertiapc)/100
+cuminertiapc <- (100*cuminertiapc)/100
+inertias <- cbind(inertia,inertiapc,cuminertiapc)
 
 ##########################################################
 if((catype=="SOCA")|(catype=="SONSCA")|(catype=="DOCA")|(catype=="DONSCA")){
 inertiasum2 <- sum(inertia2) #for column categories diag(Z'Z)
 inertiapc2 <- 100*inertia2/inertiasum2
 cuminertiapc2 <- cumsum(inertiapc2)
-inertiapc2 <- round(100*inertiapc2)/100
-cuminertiapc2 <- round(100*cuminertiapc2)/100
-inertias2 <- round(cbind(inertia2,inertiapc2,cuminertiapc2),digits=digits)
+inertiapc2 <- (100*inertiapc2)/100
+cuminertiapc2 <- (100*cuminertiapc2)/100
+inertias2 <- cbind(inertia2,inertiapc2,cuminertiapc2)
 }
 else inertias2<-inertias
 # Calc contributions and correlations
@@ -218,21 +219,75 @@ else {uni<-rep(1,rows)
 dr<-diag(uni)}
 dc <- diag(colSums(Xstd))
 dimnames(Trend)<-list(rowlabels,collabels)
-#############################
-#cacorpo<- new("cacorporateplus",S=S,
-#DataMatrix=X, rows=rows, cols=cols, 
-#rowlabels=rowlabels, collabels=collabels,
-#Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,
-# inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
-#  maxaxes=maxaxes,catype=catype,printdims=printdims,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
-#Trend=Trend,Z=Z)
-
-list(
-DataMatrix=X, rows=rows, cols=cols, r=r,
-rowlabels=rowlabels, collabels=collabels,
-Rprinccoord=Fmat[,1:r], Cprinccoord=Gmat[,1:r], Rstdcoord=Fbi[,1:r], Cstdcoord=Gbi[,1:r],tauden=tauden,tau=tau,
- inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
-  maxaxes=maxaxes,catype=catype,printdims=printdims,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
-Trend=Trend,Z=Z)
+dimnames(dr)<-list(rowlabels,rowlabels)
+dimnames(dc)<-list(collabels,collabels)
+dimnames(inertias)[[1]]<-paste("value", 1:r,sep="")
+dimnames(inertias2)[[1]]<-paste("value", 1:r,sep="")
 
+dimnames(Fmat)<-list(rowlabels,paste("axes", 1:r,sep=""))
+dimnames(Fbi)<-list(rowlabels,paste("axes", 1:r,sep=""))
+dimnames(Gmat)<-list(collabels,paste("axes", 1:r,sep=""))
+dimnames(Gbi)<-list(collabels,paste("axes", 1:r,sep=""))
+names(mi)<-rowlabels
+names(mj)<-collabels
+#---------------------------------------------------
+if (ellcomp==TRUE){
+cord1<-Gmat
+cord2<-Fmat
+if ((catype=="DOCA")|(catype=="SOCA")|(catype=="SONSCA")|(catype=="DONSCA") ){
+cordr<-cord2
+cordc<-cord1
+cord1<-cordr
+cord2<-cordc
+}
+
+risell<-switch(catype, "CA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord1,fr=cord2,dmu=diag(inertias[,1]),inertiapc=round(inertias[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+
+"SOCA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+Imass=dr,Jmass=dc,a=Fbi,b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+
+"DOCA"=caellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+Imass=dr,Jmass=dc,a=Fbi,
+b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),inertiapc=round(inertias2[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+
+"NSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+Imass=dr,Jmass=dc,a=Fbi,
+b=Gbi,g=cord1,fr=cord2,dmu=diag(inertias[,1]), tauden=tauden,
+inertiapc=round(inertias[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE),
+
+"SONSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M= Mell,prop=.8,
+Imass=dr,Jmass=dc,a=Fbi,
+b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=T,length=0,graphy=FALSE,ell=FALSE), 
+
+"DONSCA"=nscaellipse(Xtable=X,a1=1,a2=2,alpha=alpha,M=Mell,prop=1,
+Imass=dr,Jmass=dc,a=Fbi,
+b=Gbi,g=cord2,fr=cord1,dmu=diag(inertias2[,1]),tauden=tauden,inertiapc=round(inertias2[,2],digits=1),
+plottype="biplot",biptype="row",pos=1,arrow=F,length=0,graphy=FALSE,ell=FALSE))
+dimnames(risell$row.summ)[[1]]<-dimnames(X)[[1]]
+dimnames(risell$col.summ)[[1]]<-dimnames(X)[[2]]
+}#end ellcomp
+else{
+risell<-NULL}
+#############################
+#invisible(x<- new("cacorporateplus",S=S,
+#DataMatrix=X, rows=rows, cols=cols, r=r,
+#rowlabels=rowlabels, collabels=collabels,
+#Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,tauden=tauden,tau=tau,
+#inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
+#catype=catype,printdims=printdims,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
+#Trend=Trend,Z=Z))
+list(Xtable=X, rows=rows, cols=cols, r=r,
+rowlabels=rowlabels, collabels=collabels,
+Rprinccoord=Fmat, Cprinccoord=Gmat, Rstdcoord=Fbi, Cstdcoord=Gbi,tauden=tauden,tau=tau,
+ inertiasum=inertiasum, inertias=inertias, inertias2=inertias2,comps=comps,
+ catype=catype,mj=mj,mi=mi,pcc=pcc,Jmass=dc,Imass=dr,
+Trend=Trend,Z=Z,ellcomp=ellcomp,risell=risell,Mell=Mell)
+
+#-----------------------------------------------
 }
